@@ -31,6 +31,8 @@ AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
 GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
+StreamContentEntry = get_class('cms.blocks.entries', 'StreamContentEntry')
+
 SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
 
@@ -98,6 +100,7 @@ class Command(BaseCommand):
         numbers_entry = NumbersEntry()
         form_entry = FormEntry()
         gallery_entry = GalleryEntry()
+        stream_content_entry = StreamContentEntry()
 
         social_links = SocialLinks()
         social_share = SocialShare()
@@ -672,6 +675,22 @@ class Command(BaseCommand):
         mocker.menu(gallery_page, block_menu_id)
         mocker.add_menu(gallery_page, home_page_menu_id)
 
+        # -------------------------------- Stream Content --------------------------------
+
+        stream_content_page = ContentPage(
+            title="Stream Content",
+            slug='stream-content',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Stream Content</h1>', align='center'),
+                stream_content_entry.mock(),
+                stream_content_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                stream_content_entry.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=stream_content_page)
+        mocker.menu(stream_content_page, block_menu_id)
+        mocker.add_menu(stream_content_page, home_page_menu_id)
+
         # -------------------------------- Settings --------------------------------
 
         ws_settings = WebspaceSettings.for_site(site)
